#include <iostream>
#include <cstring>

using namespace std;

#define MAXN 42
#define MAXM 410
#define INF 1000000000

// val[i][j][c][d]
// what is the best way to arrange the submatrix between rows i and j-1
// starting at column c using only digits 0 through d
int val[MAXN][MAXN][MAXM][10];
char grid[MAXN][MAXM+1];
int n, m;

int solve(int i, int j, int c, char d) {
  // trivial or base cases
  if (j <= i) return 0; // no rows to change
  if (c >= m) return 0; // no columns need to be changed
  if (d < '0') return INF; // well, we have to use some digit!

  int& v = val[i][j][c][d-'0'];

  if (v == -1) {
    // don't use digit d
    v = solve(i, j, c, d-1);

    // now try all jj so rows jj to j-1 receive digit d in column c
    int change = 0; // how mow many entries were actually changed
    for (int jj = j-1; jj >= i; --jj) {
      if (grid[jj][c] != d) ++change;
      v = min(v, change + solve(i, jj, c, d-1) + solve(jj, j, c+1, '9'));
    }
  }

  return v;
}

// the same recurrence, except we already know the optimum value
// so actually modify the grid according to whichever recursive rule
// found the optimum value
void recover(int i, int j, int c, char d) {
    if (j <= i || c >= m) return;

    int v = val[i][j][c][d-'0'];

    if (solve(i, j, c, d-1) == v) {
      recover(i, j, c, d-1);
      return;
    }

    int change = 0;
    for (int jj = j-1; jj >= i; --jj) {
      if (grid[jj][c] != d) {
        ++change;
        grid[jj][c] = d;
      }
      if (v == change + solve(i, jj, c, d-1) + solve(jj, j, c+1, '9')) {
        recover(i, jj, c, d-1);
        recover(jj, j, c+1, '9');
        return;
      }
    }
}

int main() {
  memset(val, -1, sizeof(val));

  cin >> n >> m;
  for (int i = 0; i < n; ++i) cin >> grid[i];

  solve(0, n, 0, '9');
  recover(0, n, 0, '9');

  for (int i = 0; i < n; ++i) cout << grid[i] << endl;

  return 0;
}
